#
# spec file for package e17
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define efl_release 1.7.4

Name:           e17
Version:        0.17.0
Release:        2.1
License:        BSD-2-Clause
Summary:        The window manager
Url:            http://enlightenment.org/
Group:          System/X11/Displaymanagers
Source:         enlightenment-0.17.0.tar.bz2
Source2:	e17
Source3:	sysactions.conf-oS12.2
# PATCH-FEATURE-OPENSUSE enlightenment-0.16.999.65256-dont_require_suidbit.patch -- we can call dbus actions instead of suid binary sleep_walker@suse.cz
Patch0:         enlightenment-0.16.999.65256-dont_require_suidbit.patch
BuildRequires:  alsa-lib-devel
BuildRequires:  dbus-devel
BuildRequires:  doxygen
BuildRequires:  e_dbus-devel >= %efl_release
BuildRequires:  ecore-devel >= %efl_release
BuildRequires:  edje-devel >= %efl_release
BuildRequires:  eet-devel >= %efl_release
BuildRequires:  eeze-devel >= %efl_release
BuildRequires:  efreet-devel >= %efl_release
BuildRequires:  eina-devel >= %efl_release
BuildRequires:  eio-devel >= %efl_release
BuildRequires:  embryo-devel >= %efl_release
BuildRequires:  evas-devel >= %efl_release
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  xcb-util-keysyms-devel
BuildRequires:  libXext-devel
# to have dbus-send for sysactions.conf
Requires:       dbus
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Enlightenment 0.17 window manager and desktop environment is really fast, configurable and beautiful.

%package devel
Summary:        E17 development files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       dbus-devel
Requires:       e_dbus-devel >= %efl_release
Requires:       ecore-devel >= %efl_release
Requires:       edje-devel >= %efl_release
Requires:       eet-devel >= %efl_release
Requires:       eeze-devel >= %efl_release
Requires:       efreet-devel >= %efl_release
Requires:       eina-devel >= %efl_release
Requires:       eio-devel >= %efl_release
Requires:       embryo-devel >= %efl_release
Requires:       evas-devel >= %efl_release
Requires:       pkgconfig(freetype2)
Requires:       pam-devel
Requires:       libXext-devel

%description devel
Development files of E17 package.

%package branding-upstream
Summary:        E17 files for upstream branding
Group:          System/GUI/Other
%if 0%{?suse_version}
Supplements:    packageand(e17:branding-upstream)
Conflicts:      otherproviders(e17-branding)
%endif
Provides:       e17-branding = %version

%description branding-upstream
Various files for E17 provided by upstream but altered by openSUSE or Petite Linux.

%package doc-html
Summary:        HTML documentation of Enlightenment
Group:          Documentation/HTML

%description doc-html
Documentation of Enlightenment in form of HTML pages.

%package doc-man
Summary:        Man documentation of Enlightenment
Group:          Documentation/Man

%description doc-man
Documentation of Enlightenment in form of man pages.

%prep
%setup -q -n enlightenment-0.17.0
%patch0

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static --disable-silent-rules
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;
%find_lang enlightenment

%if 0%{?suse_version}
# remove setuid bits, enlightenment_backlight requires eeze-devel, which is not available for SLE
chmod -s %{buildroot}%{_libdir}/enlightenment/utils/enlightenment_sys \
%if 0%{?sles_version} != 11
         %{buildroot}%{_libdir}/enlightenment/utils/enlightenment_backlight \
%endif
         %{buildroot}%{_libdir}/enlightenment/modules/cpufreq/*/freqset

# remove duplicate files for SUSE
%fdupes -s %{buildroot}%{_libdir}/enlightenment/modules/
%fdupes -s %{buildroot}%{_datadir}/enlightenment/data/config
%endif

# copy PAM profile
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
cp %SOURCE2 %{buildroot}%{_sysconfdir}/pam.d

# replace sysactions.conf with the distribution one
%if 0%{?suse_version} >= 1220
cp %SOURCE3 %{buildroot}%{_sysconfdir}/enlightenment/sysactions.conf
%endif

%clean
%{?buildroot:rm -rf %{buildroot}}

%files -f enlightenment.lang
%defattr(-,root,root)
%{_datadir}/xsessions/enlightenment.desktop
%{_datadir}/enlightenment/
%{_datadir}/applications/*.desktop
%{_libdir}/enlightenment
%config %{_sysconfdir}/enlightenment
%config(noreplace) %{_sysconfdir}/pam.d/e17
%dir %{_sysconfdir}/xdg/menus
%config %{_sysconfdir}/xdg/menus/enlightenment.menu
%{_bindir}/enlightenment*
# excluded to be branded
%exclude %{_libdir}/enlightenment/modules/wizard/def-ibar.txt

%files branding-upstream
%defattr(-, root, root)
%{_libdir}/enlightenment/modules/wizard/def-ibar.txt

%files devel
%defattr(-, root, root)
%{_libdir}/pkgconfig/*.pc
%{_includedir}/enlightenment

%files doc-html
%defattr(-, root, root)
%{_docdir}/%{name}

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 0.17.0-2.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 0.17.0 (release)
* Fri Dec 21 2012 sleep_walker@suse.cz
- build and package documentation
* Tue Dec 18 2012 sleep_walker@suse.cz
- update to 0.17.0 omega
  Changelog:
  * Translation updates
  * Compile fixes on non-linux platforms
  * Restoring default keybindings now restores all of the default
    keybindings
  * Same as above for mouse wheel bindings
  * Fixed a number of potential buffer overflows and memory leaks
  * Even more wallpapers
  * Tiling module now handles maximization of windows more effectively
  * Improvements to Window Remembers config dialog
  * Clock gadgets now scale the date
  * Fixed issue where radio widgets could have no radio item toggled
  * Pager config dialog now shows button names
  * Tiling module improvements when moving/resizing tiled windows
  * Improved RandR dialog
  * Navigate menu's "Current Directory" now works correctly when
    activated on files and removable media
  * Filemanager no longer loses icons which caused a DND operation
    failure
  * Filemanager now properly handles DND operations where the target
    is the icon of a removable device
  * Starting with an invalid configuration is now much less likely
    (nearly impossible) to result in a complete failure
  * Triggering Everything repeatedly no longer causes a crash
  * Refresh button on filemanager toolbar is now functional
  * Scale config dialog now detects changes properly and closes on
    apply
  * Shelf changes/deletions no longer create artifacts
  * Gadgets on shelves no longer sometimes show the wrong style in menus
  * Fixed crash when filemanager preview popup was present during
    directory refresh/change
  * Fixed a number of issues which prevented various locales from
    functioning or detecting correctly
  * Main applications menu no longer generates in a thread :(
  * Filemanager toolbars can no longer trigger crashes when deleted
  * Filemanager toolbars now store their position
  * Filemanager now more capable of opening .desktop files linked to
    directories
  * Filemanager toolbar path items now create and delete correctly
  * Filemanager no longer allows renaming files into/onto directories
    and other files
  * "Show files in menu" option removed from filemanager
  * [THEME] Cursor icons
* Tue Dec 18 2012 sleep_walker@suse.cz
- make branding correct
* Mon Dec 17 2012 sleep_walker@suse.cz
- remove noarch as the test is stupid
* Mon Dec 17 2012 sleep_walker@suse.cz
- attempt to fix builds for Fedoras and CentOS
* Mon Dec 17 2012 sleep_walker@suse.cz
- improve rpm group
* Mon Dec 17 2012 sleep_walker@suse.cz
- temporary fix of build until better group is found
* Mon Dec 17 2012 sleep_walker@suse.cz
- separate first file to be rebranded
* Fri Dec 14 2012 sleep_walker@suse.cz
- update to 0.17.0-lucky
  Changelog:
  - EFL requirements now bumped to 1.7.3
  - Translation updates
  - Wallpaper previews now maintain aspect ratio when dialog is resized
  - Backlight gadgets update themselves on backlight change
  - Filemanager now capable of loading large directories more quickly
  - Filemanager "New Directory" action renames files inline
  - Menu item layout no longer resizes randomly
  - Filemanager drag-n-drop no longer causes crashes in most scenarios
  - Xmodmap settings no longer overwritten when changing keyboard layout
  - Filemanager properly shows files again if a drag-n-drop operation
    fails or pauses
  - Orientation changing on shelves no longer duplicates the shelf
  - Every file browsing now shows mime types more accurately
  - Tons of small memory leaks fixed
  - Theme selection dialog now shows actual preview of theme
    instead of wallpaper
  - Temperature module no longer leaks fds on some platforms
  - Pointer warping now more effective when changing desks
  - "Share" button on screenshot dialog now leads to a confirmation
    dialog
  - [THEME] Filemanager icons
  - [THEME] Pixel border style removed
  - [THEME] Pixel border style added
  - [THEME] Pixel border style now has focused effect
* Wed Dec 12 2012 sleep_walker@suse.cz
- cleanup default sysactions.conf, add comments for openSUSE users/admins
- require dbus-1 for sending messages through DBus (defined in
  sysactions.conf)
* Wed Dec 12 2012 sleep_walker@suse.cz
- replace invalid config for now
* Wed Dec 12 2012 sleep_walker@suse.cz
- use consolkit for shutdown/reboot
* Tue Dec 11 2012 sleep_walker@suse.cz
- update needed EFL versions to 1.7.3
- remove e17-rpmlint as we don't have evil suid binaries anymore
  (bnc#792928)
- update to 0.17.0-gamma
  Changelog:
  - Translation updates
  - Clock and cpufreq gadgets now consume less cpu
  - Slider widget can no longer explode the stack
  - Backlight setting improved, now more reliable
  - mkstemps no longer used; portability++
  - "Really move" option in filemanager renamed to something
    more descriptive
  - Resizable dialogs are now able to be maximized
  - Scrollbars now hide in more cases where they should
  - Dragging files to other applications from filemanager no
    longer causes file icon to disappear
  - Filemanager toolbar path items delete when corresponding
    path is removed
  - Mixer no longer causes a crash when pulseaudio is killed
  - Navigate menu no longer crashes when repeatedly navigating
    to a directory which has no listable contents
  - Tasks gadget no longer tries to delete its items repeatedly
  - Systray icon scaling improved
  - XDirectSave DND operations now work again
  - "hicolor" icon theme automatically applied now when no theme
    is selected
  - Fileselector no longer changes its entry text when changing
    directories
  - Filemanager "New File" action no longer creates file with
    garbage content
  - "Don't composite fullscreen windows" is now disabled by default
  - Notifications no longer do anything (including crash) when
    received during desklock
  - Gadgets module no longer crashes on unload and also correctly
    shows gadgets when loaded
  - Read-only entry widgets are now actually read-only
  - Filemanager no longer as hungry, saves some DND events for pager
    to enable drags on desktop pagers
  - Removed some potentially troublesome settings from advanced
    Composite settings
  - Systray now informs the user that it should not be placed on an
    invisible shelf
  - Window moving/resizing (and other mouse-related events) no
    longer behave strangely in the presence of autohiding shelves
  - Submenu item arrows now properly sized and aligned
  - [THEME] Lots of icons
* Thu Dec  6 2012 sleep_walker@suse.cz
- add some comments to improve readability of code
- do not change permissions of enlightenment_backlight for SLE_11*,
  this file doesn't exist there
* Thu Dec  6 2012 sleep_walker@suse.cz
- remove suid bit from binaries for SUSE
- remove rpmlint file
- remove duplicates for SUSE
* Tue Dec  4 2012 simon@simotek.net
- update to 0.17.0-alpha8
  Changelog:
  Translation updates
  Language changes now always trigger a restart
  XDG paths should no longer contain duplicate entries
  Fileselector no longer fails to open some files
  First-run wizard no longer waits unnecessarily long on subsequent runs
  FreeBSD warning fixes
  Disabling tiling module now restores original border geometry
  Composite module now uses black as its client fill color
  Desktop gadgets no longer cause crashes when immediately deleted from the config dialog
  Connman network list now sizes based on a percentage of screen size
  Various memory leaks plugged
  Filemanager once again is able to open symlinks to directories using in-place opening
  Most config dialogs have been made non-resizable
  Everything will now hide on desklock
  enlightenment_start no longer ptraces while valgrinding
  More wallpapers added (Provided by Nicolas Beaumont http://www.nicolas-beaumont.fr/)
  Compile fixes for various E17 utilities
  Crash reduction in Everything launcher
  Keybindings config dialog no longer randomly changes bindings when scrolling quickly through list
  Filemanager windows no longer appear outside screen limits
  "Focus" option in window switcher config dialog now functions correctly
  Cut/Copy/Paste now function more correctly in certain text entries
  Menus are now limited to screen size
  Filemanager sidebar scrollbars no longer appear unnecessarily
  Mixer can now set volume to 100%%
  Closing applications started by E17 no longer sometimes triggers a crash
  Pointer slide (to/from new windows) is now more reliable
  Revert focus now works correctly for mouse focus
  Pointer slide no longer sets focus during slide
  [THEME] Battery
  [THEME] Everything
* Fri Nov 30 2012 sleep_walker@suse.cz
- update to 0.17.0-alpha7
  Changelog:
  Translation updates
  DND operations in the filemanager now crash less often
  Notification gadget euthanized: too buggy to live
  Gadget for fileman_opinfo shows a red light when its window wants attention
  Birthday module added (Happy birthday raster!)
  Extremely large menus no longer align improperly
  Gadget popups once again position themselves correctly for left/top shelves
  Desktop gadgets no longer cause a crash when rotating a monitor
  Shelf autohide no longer causes a crash when triggered during a monitor
  rotation
  RandR dialog now reopens when left open during an E restart
  System action dialogs have had various text improvements
  Filemanager windows no longer unset custom border styles
  Tories rejoice, the UK flag in the first-run wizard now displays correctly
  List items will be more often deselected as intended in some cases
  Shelves may now show slightly later after startup to avoid resizing their
  canvases
  DND operations on desktop gadgets are less likely to show an ugly icon while
  dragging
  Several memory leaks plugged
  A number of desktop gadget DND-related crashes fixed
  Connman network list is now larger and refreshes more regularly
  Birthday module removed
  Mixer module no longer sometimes causes magic failures on shutdown
  Application menus now update themselves when the corresponding menu file is
  changed
  Mixer module no longer sets volume to zero on first load
  Various small dialog text improvements
  First-run wizard now runs shutdown routines for its pages
  First-run wizard's first page no longer accidentally the whole second page
  First-run wizard is now less likely to skip pages at random
  First-run wizard no longer shows the same page repeatedly in some cases
  [THEME] Temperature module
  [THEME] Backlight gadget
  [THEME] Mixer module
  [THEME] First-run wizard button no longer animates on click when disabled
* Thu Nov 29 2012 sleep_walker@suse.cz
- econnman needs efreet, not e17
* Thu Nov 29 2012 simon@simotek.net
- Add missing efreet dependency Required for connman module to find
  econnman
* Tue Nov 27 2012 sleep_walker@suse.cz
- update to 0.17.0-alpha6
  Changelog:
  * Translation updates
  * AMD K10 temperature sensor support on OpenBSD
  * Video file previews will now stutter less and respect tooltip boundaries
  more
  * Battery module now crashes less on OpenBSD
  * Icon resizing is now smoother
  * Gadget menus can no longer cause crashes when the gadget is deleted
  * Fileselector once again allows selection from directory previews
  * Filemanager DND can no longer interfere with gadget DND to cause crashes
  * Improved support for XDG_DESKTOP_DIR
  * Filemanager no longer restores non-default desktop paths when desktop
  navigation mode is disabled
  * Improvements/fixes to lost window warping behavior
  +* New ibar sources now copy from default source
  * Right clicking on any part of a desktop gadget is now sufficient to disable
  move/resize
  * Filemanager maximum thumbnail size config slider now more granular
  * Module config dialog now updates when module states are externally toggled
  * Connman wizard page now shows regardless of connman support, also disables
  connman module if support disabled
  * First-run wizard now correctly updates after language changes
  * First-run wizard button now reads "Please Wait" when it is disabled
  +* First-run wizard now has a page to (not) add a taskbar to the default shelf
  * First-run wizard now unsets winlist pointer warping when "click" focus model
  is chosen
  * First-run wizard now performs a more accurate wait when building XDG cache
  * Edge bindings dialog can no longer crash when closed before its grab dialog
  * Edge bindings dialog no longer allows blank bindings to be added
  * Keybindings dialog no longer adds non-default ctrl+shift bindings when
  restoring default bindings
  * Gadget popups will no longer sometimes obscure the source gadget if
  triggered on an offscreen gadget
  * "Show Calendar" action renamed to "Toggle Calendar"
  * Fileman Operations module now uses same infos as filemanager
  +* Password mode toggling in entry now works more effectively
  * [THEME] Desktop gadget
  +* [THEME] RandR dialog
  * [THEME] Notification module
  * [THEME] Pixel borders fixed
  * [THEME] Pixel borders allow drag resizing
  * [THEME] Cpufreq gadget
  * [THEME] Analog clock
* Sat Nov 24 2012 sleep_walker@suse.cz
- add pam profile for E17
- add sysactions for openSUSE 12.2 and above
* Sat Nov 24 2012 sleep_walker@suse.cz
- make find less efficient
- simplify make install
- clean up spec file
- require version of EFL defined by efl_release macro
* Fri Nov 23 2012 simon@simotek.net
- Alpha 5 featuring:
- More translation updates
- New default theme is more complete
- Entry widgets will no longer sometimes lock E when resizing
- First-run wizard is now smarter with regard to the signals it listens to
* Wed Nov 21 2012 sleep_walker@suse.cz
- add proper tag to patch
* Wed Nov 21 2012 sleep_walker@suse.cz
- bumb to alpha4
* Fri Nov 16 2012 sleep_walker@suse.cz
- bump to 0.17.0-alpha3
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Tue Nov 13 2012 sleep_walker@suse.cz
- add xcb-util-keysyms-devel as dependency
* Tue Nov 13 2012 sleep_walker@suse.cz
- update to 0.17.0-alpha2
- clean the spec file a bit
* Mon Nov  5 2012 simon@simotek.net
- Bump to 0.17.0-alpha
* Mon Nov  5 2012 sleep_walker@suse.cz
- change %%make_install to %%makeinstall to make SLE working again
* Sun Oct 21 2012 simon@simotek.net
- bump to new snapshot 77927
* Sat Sep 22 2012 sleep_walker@suse.cz
- make_install --> make install for fedora, mandriva, centos
* Thu Sep 20 2012 sleep_walker@suse.cz
- change pkgconfig dependency to package name
* Mon Sep 10 2012 sleep_walker@suse.cz
- reuse dropped freqset PIE patch
* Mon Sep 10 2012 sleep_walker@suse.cz
- refresh patch, remove unused one
* Sun Sep  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8214b2024fa5e75c40424527066d56051a7d3b6b
* Fri Sep  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 21b941b4f7921b0f31c7d08c76ea95fe5c6caf39
* Thu Sep  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ca66e592167098bff3a85281da3b3a94f1a57fc7
* Mon Aug 27 2012 sleep_walker@suse.cz
- added missing depenecy, bnc#774394, thanks to Simon Lees
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3e9c6d65bd44e945af56398baac2b391d7535fa7
* Fri Aug 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6a644b5195307588f28565478e6cdb91e65673cb
* Wed Aug  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8863c683589f628f76b12e4ef0c1f6b04b7f1bfa
* Fri Jul 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6398058f5897bd0806ac0424ba5bd0177daaf857
* Thu Jul 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 865ce08af1a68d5feb8fa5e44586d0bac7f752d9
* Thu Jul 19 2012 sleep_walker@suse.cz
- add freqset CFLAGS to be build as suid binary
* Sun Jul 15 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 87999dc3ff20882fb628919ea5e7c0ea0a6e228c
* Fri Jul 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3869b4635b53720cdf19ba60bdbab37ec314b073
* Fri Jul 13 2012 sleep_walker@suse.cz
- upstream now supports CFLAGS for suid binaries - removing patch
* Fri Jul 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3926c32d48b08f4529868848296309d90fc3995f
* Thu Jul 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cabc00dcd6dbc33e63caf0ace784fdeafe596309
* Thu Jul 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cabc00dcd6dbc33e63caf0ace784fdeafe596309
* Wed Jul 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision c29ec1c20547c3bc01bb6ce26adbdb0dc8cf591c
* Tue Jul 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 34f86e25b0669d5efc35fc9ab608596349011d81
* Mon Jul  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 138fa7f9130512f8e6c3ce2855e3c464d6cba57d
* Sat Jul  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5a85d7f13c40548d85925b019b8cb5c6cfe3fa1d
* Fri Jul  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 50aa874ee2ebbe2f22f8fe1c2102f545205dcfdc
* Thu Jul  5 2012 tcech@suse.com
- refresh pie patch, add new desktop file
* Thu Jul  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 37aa59c53b309d147e29161c5a0a8f9d4aeff272
* Mon Jul  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 815969d370820b4d508be01d91cf8a214b3eec3e
* Thu Jun 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b424d21170893afcfa602094972ed4a9d050efc0
* Wed Jun 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision dee5933e082b3fa6ead74c865713e594588e4af7
* Sun Jun 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a64f5e832884f0b6760749147a9b519eae7b0da3
* Fri Jun 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7903a426382de83e25a2262c84dfd8e3685884d8
* Thu Jun 21 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9514a994c8a2eb5c0d64eb1f325059d917d3099e
* Tue Jun 19 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a1a13decca87dc7a865cc2e9e65c09018891bab0
* Mon Jun 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision a754c7186e7d6eded1fe2147aa85af33c9255959
* Fri Jun 15 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1dcc07fc185962f991215eab9755b93967aa4789
* Thu Jun 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 84bbcba710c9b6cf9014bad3a245b181cab6369d
* Wed Jun 13 2012 pgajdos@suse.com
- build suid binaries as position independent executables
* Tue Jun 12 2012 sleep_walker@suse.cz
- fix typo in condition
* Mon Jun 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ac9b962c9acc497f58a95ad607c6c04c282ef3b6
* Mon Jun 11 2012 sleep_walker@suse.cz
- add fdupes for SUSE distros
* Mon Jun 11 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 25dfe1f05d8b677bab1b0d8ec0ef88f98ea53c56
* Fri Jun  8 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0bdcb0ad643836fb5244c09cb1138aa19a64d6b8
* Thu Jun  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9e5614ea4098ba689f5302e2fcd180ba4c348ae8
* Tue Jun  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 729690cff9b2323e15ad2bc32f3d4eef01ab07c4
* Mon Jun  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fe27cd23c049e7474952423fa410434db4c272b7
* Fri Jun  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 006b84bb84eb156dac2bb86913ee79540bb3288d
* Thu May 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fd7bc3e8d736346b4e7f76f944609cc2c70d7ea9
* Mon May 21 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 285b0144201c59a964898ebe6377901be8f4a373
* Fri May 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0c0f97d18d2801b953abc2a2e69d9670774ff6e0
* Mon May 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision f71607879d955df7233ed6c34f8335feb7de19c7
* Mon May  7 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1afbfb120866df202165cb840f601570610f5b85
* Fri May  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8ab53fee63bbcfaac6069018a6127f7b96705227
* Thu May  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0e6b1b2b0c3275e08c2379dee3a636744243b3dd
* Thu May  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 56ac824782ef493c25a95beefa17ad82db84e655
* Mon Apr 30 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ca3265fefd8efba3a2e1ed873a8cc81cbe45661f
* Fri Apr 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 4690d66374a4aa75d93c4d54e06cc5af426a5d8a
* Thu Apr 26 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e79253037fced8442349dc52d5847a0fd64eb1aa
* Tue Apr 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e35d8c3a3aa077992adb1caf3744ddf9a2c8e4e8
* Mon Apr 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5b463e6c7e173df741c63a54d0f0d224f93de065
* Fri Apr 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d7b8e139f399140df927cf69b1761f55f6007e47
* Tue Apr 17 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 01aeff90af1fe2b6d05361221b8c86199f58c82d
* Mon Apr 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8e9755d74c56d981981f984573569eeb8282d7a5
* Fri Apr 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 633b50f7d4fb8b9c8e6ab69178a1b66e451eec7d
* Thu Apr 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 45974747176f7e1aaaccec85add5354d6d3427fa
* Thu Apr 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 78987cf5017a5216bc78efd020835d1f1bbefdec
* Tue Apr 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision db5cf538bf0aad4edf093b63af7f1c313eca191b
* Tue Apr 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d2d4074a70221b46271fcfb156244ac79ac1bfab
* Mon Apr  9 2012 sleep_walker@suse.cz
- make configuration files as %%config(noreplace)
* Fri Apr  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 328903b6b3434ead156237aee24a5cc44408dbfe
* Thu Apr  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ec62a8857d75e463d39d18d1712c27b68dadbe85
* Tue Apr  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision c6f453b0bf90ee893c80600cb7bdaf3dc225d3de
* Mon Apr  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9e67756279078611798e4be672ce1112b562db3c
* Thu Mar 29 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 04a84aaa38afa4e0cb7b875c2b472594358a10ca
* Wed Mar 28 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision ce35e7d87d52666dc099b02deb5496742bf8d5b6
* Tue Mar 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e7d6fbc129884b37e6b5faadf73ebc213d31d843
* Wed Mar 14 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9eee4a77367e566072e975d223eef23e4ef9d65e
* Tue Mar 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2d8ab46d4d51f06cb0af1adc10e4aae80fb64d89
* Mon Mar 12 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision adc7ae955768cc49827b3a145786b45b209bb409
* Fri Mar  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 62523444edd37081d1efd794c9e3fed535f443d4
* Thu Mar  8 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision fffd7a4a123fb0df97b1cef33dacb9a9de3d8f2a
* Mon Mar  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 95c8bc7a5569ad606ec29d7dc4f96ef75f3f2ebe
* Thu Mar  1 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 5f4c74179b75e4dc75ddf7b5d067c7efcf2e6331
* Mon Feb 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0c171cac89afd2c43e1e2b7dce5a0e35a9fbbd5c
* Fri Feb 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision e99db500a967d76bee69b0cda1d4e77e3148cfab
* Thu Feb 23 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision f49d17165da1758f7d9df07548488b89d992b1db
* Wed Feb 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2bd739d7eebe60df5e434eefa98ad68742e38d04
* Tue Feb 21 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 8c2155d74f5a8fc42501bdd25441c08c1dca4129
* Thu Feb 16 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 9843bcb8eae0fd953c241abfa82a25c7b1416c18
* Mon Feb 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 1a41efba233f2d53aa357ccb9ed84be9baa00ac0
* Thu Feb  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision cba0bc9833689900930272fa5c4a2cd2529d3028
* Sun Feb  5 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision dad1020a724d7170e73a1467776953d9a53fb63b
* Sat Feb  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b92ca076d35651233e1c1de6b75c0c96dde18a09
* Fri Jan 27 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 3db544167c096fc1efed693d3c2ed9d5a6992b29
* Wed Jan 25 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2cf996f1f406d311ac158d0226bbf4a70a927c5d
* Tue Jan 24 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7fda0125b5bd7727cfb18b63e83ae4f6234746df
* Sun Jan 22 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6205634c619268739c4750ee6f7051955df81b51
* Fri Jan 20 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 209fc897801aef69955346fd708f299b36ac41d9
* Wed Jan 18 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7f0251de99307ca28e278f4675394a29983de9c4
* Fri Jan 13 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 02365193f314c71f16228e700aa83e519920a2f5
* Tue Jan 10 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b170f5b958e0f501030a42547d387ee82d6de781
* Mon Jan  9 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 92a9c98d91a9ae71cfc44da9009d8bfa4bbc4f3c
* Fri Jan  6 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 7a7e546a9a383357279a388addd220e43966b044
* Wed Jan  4 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision d335434b29c50543c6ad7c409b766a7843a2527c
* Tue Jan  3 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision b0622f20293351c844d9ddd894faa1cc84d3a268
* Mon Jan  2 2012 sleep_walker@suse.cz
- source_grabber autoupdate to revision 56a3916b994925b06531f39deb680ffc629f3131
* Sat Dec 31 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision fcc2d197b930254b4fff5ca5319f8125d9a0473c
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Wed Dec 28 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 2705be9ab47d850bc2de28c666ac1eccde669e20
* Wed Dec 28 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 090fef69a183b97716995c6f9a2449b5d6ff5d2b
* Tue Dec 27 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision ef3331a247b9cf221523073b78033b028e600ae7
* Thu Dec 22 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision b943bd062ea20f604be2f6beda3010d1f9a1f154
* Wed Dec 21 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 36a39b7d86a8f7609ce3592f2f61fe2bdf430da1
* Tue Dec 20 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 6553e66c6e339e560372de9b7847a0fe74505305
* Sun Dec 18 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 0fb63373d2cab369eb09c532598b2b7fb3fa1de7
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision c21d11c8df5658216d5c89e7a3a14b24bd49ac72
* Fri Dec 16 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision fa00cc550866e5ccaa5a14a07d3f055c0eb0418d
* Sun Dec 11 2011 sleep_walker@suse.cz
- source_grabber autoupdate to revision 90ff3488d8c1dba58b2e8530a816317d4b0480eb
* Tue Nov 15 2011 tcech@suse.com
- bump version to 0.16.999.65256
* Mon Nov 14 2011 tcech@suse.com
- bump version to 0.16.999.65190
* Tue Nov  8 2011 tcech@suse.com
- and add e_module-notification into provides
* Mon Nov  7 2011 tcech@suse.com
- obsolete e_module-notification since it became part of e17
* Sat Nov  5 2011 tcech@suse.com
- bump version to 0.16.999.64753
* Sat Nov  5 2011 tcech@suse.com
- bump version to 0.16.999.64752
* Wed Nov  2 2011 sleep_walker@suse.cz
- e17 now requires eeze
* Sat Oct 29 2011 tcech@suse.com
- bump version to 0.16.999.64511
* Mon Oct 24 2011 tcech@suse.com
- do not autoreconf on SLE_10_SDK
* Mon Oct 24 2011 tcech@suse.com
- bump version to 0.16.999.64355
* Fri Oct 21 2011 tcech@suse.com
- bump version to 0.16.999.64280
* Wed Oct 19 2011 tcech@suse.com
- bump version to 0.16.999.64163
* Tue Oct 18 2011 tcech@suse.com
- add alsa-devel into dependencies (to make mixer module working)
* Tue Oct 18 2011 tcech@suse.com
- add gettext-devel to buildrequires
* Sun Oct 16 2011 tcech@suse.com
- add autoreconf before configure
* Sun Oct 16 2011 tcech@suse.com
- bump version to 0.16.999.64119
* Sun Oct 16 2011 tcech@suse.com
- add devel packages required to build as required for devel package
* Sat Oct 15 2011 tcech@suse.com
- add embryo into buildrequires
* Sat Oct 15 2011 tcech@suse.com
- add evas into buildrequires
* Fri Oct 14 2011 jreidinger@suse.com
- bump version to 0.16.999.64070
* Thu Oct 13 2011 jreidinger@suse.com
- bump version to 0.16.999.64050
* Wed Oct 12 2011 tcech@suse.com
- bump version to 0.16.999.64026
* Tue Oct 11 2011 jreidinger@suse.com
- bump version to 0.16.999.63983
* Mon Oct 10 2011 jreidinger@suse.com
- bump version to 0.16.999.63939
* Sat Oct  8 2011 tcech@suse.com
- add pam-devel into dependencies
* Wed Oct  5 2011 jreidinger@suse.com
- bump version to 0.16.999.63840
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 0.16.999.63809
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 0.16.999.63808
* Tue Oct  4 2011 jreidinger@suse.com
- tweak spec file and fix build
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 0.16.999.63797
* Tue Oct  4 2011 jreidinger@suse.com
- bump version to 0.16.999.63797
* Mon Oct  3 2011 jreidinger@suse.com
- bump version to 0.16.999.63770
* Thu Sep 29 2011 tcech@suse.com
- change pkgconfig dependencies to package names
- remove lang package, add its files to main package
* Tue Sep 27 2011 jreidinger@suse.com
- rename to e17
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package, latest snapshot currently available.
